@@ -55,6 +55,10 @@ main = do
                          "1.22.2.0"
                        , "1.22.3.0"
                        , "1.22.4.0"
+                       , "1.22.5.0"
+                       , "1.22.6.0"
+                       ]),
+               ("8.0", [
                        ])
              ]
 
